pub enum CapabilitySupportLevel {
Unavailable,
Fallback,
Supported,
}Expand description
Independently achieved support for one language capability axis.
Variants
The capability has not been accepted or proved.
Fallback
Conservative heuristic behavior exists and is reported as fallback.
Supported
The capability is supported by its declared owner and fixtures.
Implementations