pub fn validate_language_registry() -> Result<(), LanguageRegistryError>Expand description
Validate the accepted registry and all generated projections.
Errors
Returns the first deterministic conflict or incomplete accepted row.
pub fn validate_language_registry() -> Result<(), LanguageRegistryError>Validate the accepted registry and all generated projections.
Returns the first deterministic conflict or incomplete accepted row.