pub struct LanguageCapabilitySupport {
pub detected: CapabilitySupportLevel,
pub parsed: CapabilitySupportLevel,
pub symbols: CapabilitySupportLevel,
pub semantic: CapabilitySupportLevel,
pub benchmarked: CapabilitySupportLevel,
}Expand description
Independent language capability axes.
Fields
detected: CapabilitySupportLevelThe language can be selected deterministically.
parsed: CapabilitySupportLevelSource can be parsed at the declared quality level.
symbols: CapabilitySupportLevelDefinitions and relationships can be extracted at the declared quality level.
semantic: CapabilitySupportLevelProject-wide semantic resolution has been independently validated.
benchmarked: CapabilitySupportLevelRepresentative benchmark coverage exists.
Implementations
Sourceimpl LanguageCapabilitySupport
impl LanguageCapabilitySupport
Sourcepub const fn new(
detected: CapabilitySupportLevel,
parsed: CapabilitySupportLevel,
symbols: CapabilitySupportLevel,
semantic: CapabilitySupportLevel,
benchmarked: CapabilitySupportLevel,
) -> Self
pub const fn new( detected: CapabilitySupportLevel, parsed: CapabilitySupportLevel, symbols: CapabilitySupportLevel, semantic: CapabilitySupportLevel, benchmarked: CapabilitySupportLevel, ) -> Self
Build one independent capability profile.